#
# spec file for package maven-reporting-impl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-reporting-impl
Version:        4.0.0
Release:        1.1
Summary:        Abstract classes to manage report generation
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/shared/%{name}
Source0:        %{name}-%{version}.tar.xz
Source1:        http://www.apache.org/licenses/LICENSE-2.0.txt
Source2:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  maven-archiver
BuildRequires:  maven-doxia-core
BuildRequires:  maven-doxia-module-xhtml5
BuildRequires:  maven-doxia-sink-api
BuildRequires:  maven-doxia-sitetools
BuildRequires:  maven-lib
BuildRequires:  maven-plugin-annotations
BuildRequires:  maven-reporting-api >= 4
BuildRequires:  maven-resolver-api
BuildRequires:  maven-shared-utils
BuildRequires:  plexus-utils
BuildRequires:  sisu-plexus
BuildArch:      noarch

%description
Abstract classes to manage report generation, which can be run both:

* as part of a site generation (as a maven-reporting-api's MavenReport),
* or as a direct standalone invocation (as a maven-plugin-api's Mojo).

This is a replacement package for maven-shared-reporting-impl

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q
cp %{SOURCE1} LICENSE.txt
cp %{SOURCE2} build.xml

# integration tests try to download stuff from the internet
# and therefore they don't work in Build Service
%pom_remove_plugin :maven-invoker-plugin

%build
mkdir -p lib
build-jar-repository -s lib \
    maven-archiver/maven-archiver \
    maven-doxia/doxia-core \
    maven-doxia/doxia-module-xhtml5 \
    maven-doxia/doxia-sink-api \
    maven-doxia-sitetools/doxia-integration-tools \
    maven-doxia-sitetools/doxia-site-model \
    maven-doxia-sitetools/doxia-site-renderer \
    maven/maven-artifact \
    maven/maven-core \
    maven/maven-model \
    maven/maven-plugin-api \
    maven-plugin-tools/maven-plugin-annotations \
    maven-reporting-api/maven-reporting-api \
    maven-resolver/maven-resolver-api \
    maven-shared-utils/maven-shared-utils \
    org.eclipse.sisu.plexus \
    plexus/utils

ant jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
%add_maven_depmap %{name}/%{name}.pom %{name}/%{name}.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE.txt
%doc README.md

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE.txt

%changelog
* Sat Oct 12 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 4.0.0
  * Bug
    + MSHARED-1275: MavenReport#canGenerateReport() is invoked twice
  * New Feature
    + MSHARED-390: Add startSection method
    AbstractMavenReportRenderer where anchor != name
    + MSHARED-1168: Add support for markup output
    + MSHARED-1185: Introduce
    AbstractMavenReportRenderer#verbatimSource()
  * Improvement
    + MSHARED-480: Use maven-site-plugin's site.xml to use site's
    skin instead of default when run as mojo
    + MSHARED-1099: Render with a skin when report is run in
    standalone mode
    + MSHARED-1106: Improve and simplify section handling
    + MSHARED-1174: Don't wrap elements in anchors
    + MSHARED-1181: Populate SiteRenderingContext#getPublishDate()
    with ${project.build.outputTimestamp}
    + MSHARED-1182: Drop incorrect usage of
    SinkEventAttributeSet#BOXED
    + MSHARED-1183: Don't pass implied args to
    AbstractMavenReportRenderer#startTable()
    + MSHARED-1184: Drop unnecessary use of type attribute with
    JavaScript
    + MSHARED-1232: Properly populate
    DocumentRenderingContext#generator when run in standalone mode
    + MSHARED-1295: Have ${project.build.outputTimestamp} injected
    as @Parameter
    + MSHARED-1314: mark execute() final to avoid users extending
    reporting-impl implementation
    + MSHARED-1327: Change default value of output directory in
    AbstractMavenReport
    + MSHARED-1328: Consistently log when skipping report goal
    execution
    + MSHARED-1343: Make parameter outputDirectory read/write in
    AbstractMavenReport
    + MSHARED-1438: Provide protected methods for XRef location
    construction
  * Task
    + MSHARED-1055: Upgrade to Java 8
    + MSHARED-1326: Improve MavenReport interface /
    AbstractMavenReport class API
- Fetch sources using source service from Github
- Removed patch:
  * 0001-Remove-dependency-on-junit-addons.patch
    + not needed with this version
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Sun Sep 24 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 3.2.0
  * Improvement:
    + MSHARED-1099 - Render with a skin when report is run in
    standalone mode
  * Dependency upgrades:
    + MSHARED-1120 - Upgrade Maven Reporting API to 3.1.1
    + MSHARED-1121 - Upgrade plugins and components in project and
    ITs
- Modified patch:
  * 0001-Remove-dependency-on-junit-addons.patch
    + rediff
* Wed Sep  6 2023 Fridrich Strba <fstrba@suse.com>
- Remove unnecessary dependency on xmvn tools and parent pom
* Fri Mar 11 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 3.1.0
  * API sync with maven-reporting-api 3.1.0
- Modified patch:
  * 0001-Remove-dependency-on-junit-addons.patch
    + rediff
* Wed Mar 11 2020 Fridrich Strba <fstrba@suse.com>
- Fix build against newer doxia that requires html5 module
* Fri Mar 29 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-reporting-impl 3.0.0
- Generate and customize ant build.xml file
